# molecule-k3d

molecule-k3d - Molecule K3D Driver allows Molecule users to test Ansible code using K3D.

## Testing

To execute unit tests.

    $ make dep
    $ make test

## License

The [MIT] License.

[MIT]: LICENSE
